MobileU MOOC
============

The MobileU MVP framework allows other developers to easily build mobile
education sites.

|mobileu-ci|_


Installation
~~~~~~~~~~~~

::

    $ virtualenv ve
    $ source ve/bin/activate
    (ve)$ pip install -r requirements.txt

Run Tests
~~~~~~~~~

::

    $ source ve/bin/activate
    (ve)$ python manage.py test



.. |mobileu-ci| image:: https://magnum.travis-ci.com/praekelt/mobileu.svg?token=fFyy7nhP4syfyy2MySbK&branch=feature/issue-7-add-a-readme
.. _mobileu-ci: https://magnum.travis-ci.com/praekelt/mobileu
